==> camunda-engine-7.2.0-sources.jar: org/camunda/bpm/engine/impl/cmd/PatchTaskVariablesCmd.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.cmd;

import java.io.Serializable;
import java.util.Collection;
import java.util.Map;

import org.camunda.bpm.engine.impl.interceptor.Command;
import org.camunda.bpm.engine.impl.interceptor.CommandContext;

/**
 * Patches task variables: First, applies modifications to existing variables and then deletes
 * specified variables.
 *
 * @author kristin.polenz@camunda.com
 *
 */
public class PatchTaskVariablesCmd implements Command<Void>, Serializable {

  private static final long serialVersionUID = 1L;

  protected String taskId;
  protected Map<String, ? extends Object> modifications;
  protected Collection<String> deletions;
  protected boolean isLocal;

  public PatchTaskVariablesCmd(String taskId, Map<String, ? extends Object> modifications, Collection<String> deletions, boolean isLocal) {
    this.modifications = modifications;
    this.deletions = deletions;
    this.taskId = taskId;
    this.isLocal = isLocal;
  }

  @Override
  public Void execute(CommandContext commandContext) {
    new SetTaskVariablesCmd(taskId, modifications, isLocal).execute(commandContext);
    new RemoveTaskVariablesCmd(taskId, deletions, isLocal).execute(commandContext);
    return null;
  }

}

==> camunda-engine-7.8.0-sources.jar: org/camunda/bpm/engine/impl/cmd/PatchTaskVariablesCmd.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.camunda.bpm.engine.impl.cmd;

import java.util.Collection;
import java.util.Map;

import org.camunda.bpm.engine.impl.interceptor.CommandContext;
import org.camunda.bpm.engine.impl.persistence.entity.PropertyChange;

/**
 * Patches task variables: First, applies modifications to existing variables and then deletes
 * specified variables.
 *
 * @author kristin.polenz@camunda.com
 *
 */
public class PatchTaskVariablesCmd extends AbstractPatchVariablesCmd {

  private static final long serialVersionUID = 1L;

  public PatchTaskVariablesCmd(String taskId, Map<String, ? extends Object> modifications, Collection<String> deletions, boolean isLocal) {
    super(taskId, modifications, deletions, isLocal);
  }

  protected AbstractSetVariableCmd getSetVariableCmd() {
    return new SetTaskVariablesCmd(entityId, variables, isLocal);
  }

  protected AbstractRemoveVariableCmd getRemoveVariableCmd() {
    return new RemoveTaskVariablesCmd(entityId, deletions, isLocal);
  }

  public void logVariableOperation(CommandContext commandContext) {
    commandContext.getOperationLogManager().logVariableOperation(getLogEntryOperation(), null, entityId,
      PropertyChange.EMPTY_CHANGE);
  }
}
